MonarchDiscoveryApiServiceBase class abstract

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getPreviewApi(ServiceCall call, Empty request) Future<ServerInfo>
getPreviewApi_Pre(ServiceCall call, Future<Empty> request) Future<ServerInfo>
getPreviewNotificationsApiList(ServiceCall call, Empty request) Future<ServerListInfo>
getPreviewNotificationsApiList_Pre(ServiceCall call, Future<Empty> request) Future<ServerListInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerPreviewApi(ServiceCall call, ServerInfo request) Future<Empty>
registerPreviewApi_Pre(ServiceCall call, Future<ServerInfo> request) Future<Empty>
registerPreviewNotificationsApi(ServiceCall call, ServerInfo request) Future<Empty>
registerPreviewNotificationsApi_Pre(ServiceCall call, Future<ServerInfo> request) Future<Empty>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited